@@ -1,8 +1,11 @@
-package Acme::CPANAuthors::Austrian;
 use 5.006;
 use strict;
 use warnings;
-our $VERSION = '0.09';
+
+package Acme::CPANAuthors::Austrian;
+our $VERSION = '1.100710';
+# ABSTRACT: We are Austrian CPAN authors
+
 use Acme::CPANAuthors::Register (
     ANDK     => 'Andreas J. König',
     AREIBENS => 'Alfred Reibenschuh',
@@ -23,12 +26,19 @@ use Acme::CPANAuthors::Register (
     ZEYA     => 'Hansjörg Pehofer',
 );
 1;
+
+
 __END__
+=pod
 
 =head1 NAME
 
 Acme::CPANAuthors::Austrian - We are Austrian CPAN authors
 
+=head1 VERSION
+
+version 1.100710
+
 =head1 SYNOPSIS
 
    use Acme::CPANAuthors;
@@ -54,32 +64,39 @@ If you are an Austrian CPAN author and are not listed here, please mail me.
 
 L<Acme::CPANAuthors> - Main class to manipulate this one.
 
+=head1 INSTALLATION
+
+See perlmodinstall for information and options on installing Perl modules.
+
 =head1 BUGS AND LIMITATIONS
 
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org>.
-
-=head1 INSTALLATION
-
-See perlmodinstall for information and options on installing Perl modules.
+L<http://rt.cpan.org/Public/Dist/Display.html?Name=Acme-CPANAuthors-Austrian>.
 
 =head1 AVAILABILITY
 
 The latest version of this module is available from the Comprehensive Perl
-Archive Network (CPAN). Visit <http://www.perl.com/CPAN/> to find a CPAN
-site near you. Or see L<http://search.cpan.org/dist/Acme-CPANAuthors-Austrian/>.
+Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
+site near you, or see
+L<http://search.cpan.org/dist/Acme-CPANAuthors-Austrian/>.
+
+The development version lives at
+L<http://github.com/hanekomu/Acme-CPANAuthors-Austrian/>.
+Instead of sending patches, please fork this project using the standard git
+and github infrastructure.
 
 =head1 AUTHOR
 
-Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
+  Marcel Gruenauer <marcel@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008-2009 by Marcel GrE<uuml>nauer
+This software is copyright (c) 2008 by Marcel Gruenauer.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
